@@ -5,9 +5,28 @@
 */
 
 #include "manualconfigurationtest.h"
-#include "manualconfiguration.h"
+#include "manualconfigurationbase.h"
 #include <QTest>
 QTEST_MAIN(ManualConfigurationTest)
+class ManualConfigurationImplTest : public ManualConfigurationBase
+{
+public:
+    explicit ManualConfigurationImplTest(QObject *parent = nullptr)
+        : ManualConfigurationBase(parent)
+    {
+    }
+
+protected:
+    void createTransport() override
+    {
+        // TODO
+    }
+    void generateResource(const Resource::ResourceInfo &info) override
+    {
+        // TODO
+    }
+};
+
 ManualConfigurationTest::ManualConfigurationTest(QObject *parent)
     : QObject{parent}
 {
@@ -15,7 +34,7 @@ ManualConfigurationTest::ManualConfigurationTest(QObject *parent)
 
 void ManualConfigurationTest::shouldHaveDefaultValues()
 {
-    ManualConfiguration w;
+    ManualConfigurationImplTest w;
     QVERIFY(w.incomingHostName().isEmpty());
     QVERIFY(w.incomingUserName().isEmpty());
     QVERIFY(w.outgoingHostName().isEmpty());
