@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -57,8 +57,9 @@ Resource::~Resource() = default;
 
 void Resource::createResource()
 {
-    if (mResourceInfo.isValid()) {
+    if (!mResourceInfo.isValid()) {
         qCWarning(ACCOUNTWIZARD_LOG) << "mResourceInfo is not valid. It's a bug.";
+        qCWarning(ACCOUNTWIZARD_LOG) << " mResourceInfo " << mResourceInfo;
         deleteLater();
         return;
     }
@@ -121,7 +122,10 @@ void Resource::instanceCreateResult(KJob *job)
             const QMetaType::Type targetType = argumentType(iface.metaObject(), methodName);
             if (arg.metaType().id() != targetType) {
                 Q_EMIT error(i18n("Could not convert value of setting '%1' to required type %2.", it.key(), QLatin1String(QMetaType(targetType).name())));
-                qCWarning(ACCOUNTWIZARD_LOG) << "Impossible to convert argument : " << arg;
+
+                qCWarning(ACCOUNTWIZARD_LOG) << "Impossible to convert argument : " << arg
+                                             << QStringLiteral("Could not convert value of setting '%1' to required type %2.")
+                                                    .arg(it.key(), QLatin1String(QMetaType(targetType).name()));
                 return;
             }
             // arg.convert(targetType);
